@@ -25,11 +25,11 @@
 /* EXTERNAL PROCEDURES- - - - - - - - - - - - - - - - - - - - - - - - - */
 /* EXTERNAL DATA- - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 /* PROTOTYPES - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-void do_play(char *progname, int cdfile, int trk0, int trk1);
-void do_pause(char *progname, int cdfile);
-void do_stop(char *progname, int cdfile);
-void do_eject(char *progname, int cdfile);
-void do_reset(char *progname, int cdfile);
+void do_play(char *progname, int cdfile, int trk0, int trk1, int iVerbose);
+void do_pause(char *progname, int cdfile, int iVerbose);
+void do_stop(char *progname, int cdfile, int iCDNum, int iVerbose);
+void do_eject(char *progname, int cdfile, int iVerbose);
+void do_reset(char *progname, int cdfile, int iVerbose);
 /*
  * Copyright (C) 1997, 1998 Wade Hampton
  */
